@@ -21,15 +21,14 @@
 
 #include "acpidLogMode.h"
 
-
 #include <KLocalizedString>
 
 #include "logging.h"
 
 #include "acpidAnalyzer.h"
-#include "acpidItemBuilder.h"
-#include "acpidConfigurationWidget.h"
 #include "acpidConfiguration.h"
+#include "acpidConfigurationWidget.h"
+#include "acpidItemBuilder.h"
 
 AcpidLogMode::AcpidLogMode()
     : LogMode(QStringLiteral(ACPID_LOG_MODE_ID), i18n("ACPI Log"), QStringLiteral(ACPID_MODE_ICON))
@@ -42,11 +41,11 @@ AcpidLogMode::AcpidLogMode()
 
     d->action = createDefaultAction();
     d->action->setToolTip(i18n("Display the ACPI log."));
-    d->action->setWhatsThis(i18n(
-        "Displays the ACPI log in the current tab. ACPI is used to manage the hardware components of your "
-        "computer, like notebook batteries, reset buttons..."));
+    d->action->setWhatsThis(
+        i18n("Displays the ACPI log in the current tab. ACPI is used to manage the hardware components of your "
+             "computer, like notebook batteries, reset buttons..."));
 
-    AcpidConfiguration *configuration = logModeConfiguration<AcpidConfiguration *>();
+    auto *configuration = logModeConfiguration<AcpidConfiguration *>();
     checkLogFilesPresence(configuration->acpidPaths());
 }
 
@@ -60,8 +59,8 @@ Analyzer *AcpidLogMode::createAnalyzer(const QVariant &options)
     return new AcpidAnalyzer(this);
 }
 
-QList<LogFile> AcpidLogMode::createLogFiles()
+QVector<LogFile> AcpidLogMode::createLogFiles()
 {
-    AcpidConfiguration *configuration = logModeConfiguration<AcpidConfiguration *>();
+    auto *configuration = logModeConfiguration<AcpidConfiguration *>();
     return configuration->findNoModeLogFiles(configuration->acpidPaths());
 }
