@@ -21,19 +21,17 @@
 
 #include "authenticationLogMode.h"
 
-
 #include <KLocalizedString>
 
 #include "logging.h"
 
 #include "authenticationAnalyzer.h"
-#include "logModeItemBuilder.h"
-#include "authenticationConfigurationWidget.h"
 #include "authenticationConfiguration.h"
+#include "authenticationConfigurationWidget.h"
+#include "logModeItemBuilder.h"
 
 AuthenticationLogMode::AuthenticationLogMode()
-    : LogMode(QStringLiteral(AUTHENTICATION_LOG_MODE_ID), i18n("Authentication Log"),
-              QStringLiteral(AUTHENTICATION_MODE_ICON))
+    : LogMode(QStringLiteral(AUTHENTICATION_LOG_MODE_ID), i18n("Authentication Log"), QStringLiteral(AUTHENTICATION_MODE_ICON))
 {
     d->logModeConfiguration = QSharedPointer<AuthenticationConfiguration>(new AuthenticationConfiguration());
 
@@ -43,11 +41,11 @@ AuthenticationLogMode::AuthenticationLogMode()
 
     d->action = createDefaultAction();
     d->action->setToolTip(i18n("Display the authentication log."));
-    d->action->setWhatsThis(i18n(
-        "Displays the authentication log in the current tab. This log displays all logins made by each user "
-        "of the system, and can help you to know if someone tried to crack your system."));
+    d->action->setWhatsThis(
+        i18n("Displays the authentication log in the current tab. This log displays all logins made by each user "
+             "of the system, and can help you to know if someone tried to crack your system."));
 
-    AuthenticationConfiguration *configuration = logModeConfiguration<AuthenticationConfiguration *>();
+    auto *configuration = logModeConfiguration<AuthenticationConfiguration *>();
     checkLogFilesPresence(QStringList() << configuration->authenticationPath());
 }
 
@@ -61,11 +59,10 @@ Analyzer *AuthenticationLogMode::createAnalyzer(const QVariant &options)
     return new AuthenticationAnalyzer(this);
 }
 
-QList<LogFile> AuthenticationLogMode::createLogFiles()
+QVector<LogFile> AuthenticationLogMode::createLogFiles()
 {
-    AuthenticationConfiguration *configuration = logModeConfiguration<AuthenticationConfiguration *>();
+    auto *configuration = logModeConfiguration<AuthenticationConfiguration *>();
 
-    QList<LogFile> logFiles;
-    logFiles.append(configuration->findGenericLogFile(configuration->authenticationPath()));
+    const QVector<LogFile> logFiles{configuration->findGenericLogFile(configuration->authenticationPath())};
     return logFiles;
 }
